Ecdh

Struct Ecdh 

pub struct Ecdh;
Stateless ECDH helper.

Implementations

Source

impl Ecdh

pub fn derive_public_key<P, const LIMBS: usize>( base_point: &P, secret: &SecretScalar<LIMBS>, curve: &P::Curve, ) -> P
where P: PointOps,

Derive a public key [secret]G from a fixed generator/base point.

pub fn keypair_from_secret<P, const LIMBS: usize>( base_point: &P, secret: SecretScalar<LIMBS>, curve: &P::Curve, ) -> KeyPair<P, LIMBS>
where P: PointOps,

Build a deterministic key pair from a secret scalar.

pub fn shared_secret<P, const LIMBS: usize>( my_secret: &SecretScalar<LIMBS>, peer_public: &P, curve: &P::Curve, ) -> Option<P>
where P: PointOps,

Compute a shared point [my_secret] peer_public.

Returns None when the peer public key is the identity.