[−][src]Enum protocol::ByteOrder
Specifies the byte order of data transfer.
Eq implementation
Here is a list of rules the Eq implementation satisfies.
LittleEndian == LittleEndianLittleEndian != BigEndianNativeEndian == LittleEndian(but only on little endian machines)NativeEndian == BigEndian(but only on big endian machines)
The NativeEndian byte order will successfully match against
one of the two real-life byte orders.
Variants
Least significant byte first.
Most significant byte first.
Whatever the byte ordering of the current machine is.
Implementations
impl ByteOrder[src]
pub fn read_u16(&self, read: &mut dyn Read) -> Result<u16, Error>[src]
pub fn write_u16(&self, value: u16, write: &mut dyn Write) -> Result<(), Error>[src]
pub fn read_i16(&self, read: &mut dyn Read) -> Result<i16, Error>[src]
pub fn write_i16(&self, value: i16, write: &mut dyn Write) -> Result<(), Error>[src]
pub fn read_u32(&self, read: &mut dyn Read) -> Result<u32, Error>[src]
pub fn write_u32(&self, value: u32, write: &mut dyn Write) -> Result<(), Error>[src]
pub fn read_i32(&self, read: &mut dyn Read) -> Result<i32, Error>[src]
pub fn write_i32(&self, value: i32, write: &mut dyn Write) -> Result<(), Error>[src]
pub fn read_u64(&self, read: &mut dyn Read) -> Result<u64, Error>[src]
pub fn write_u64(&self, value: u64, write: &mut dyn Write) -> Result<(), Error>[src]
pub fn read_i64(&self, read: &mut dyn Read) -> Result<i64, Error>[src]
pub fn write_i64(&self, value: i64, write: &mut dyn Write) -> Result<(), Error>[src]
pub fn read_f32(&self, read: &mut dyn Read) -> Result<f32, Error>[src]
pub fn write_f32(&self, value: f32, write: &mut dyn Write) -> Result<(), Error>[src]
pub fn read_f64(&self, read: &mut dyn Read) -> Result<f64, Error>[src]
pub fn write_f64(&self, value: f64, write: &mut dyn Write) -> Result<(), Error>[src]