Reader

Struct Reader 

pub struct Reader { /* private fields */ }
A receive buffer that waits until enough data is ready and then returns the parsed parcels.

This mechanism can be used to send parcels without length prefixes.

Adding data to the receive buffer

Reader implements std::io::Write. Any bytes written to the reader are added to the receive queue for future processing.

Example

This example shows a reader only returning a u32 once enough data has been buffered.

use protocol;
use std::io::Write;

let mut reader = protocol::wire::Reader::new();
let settings = protocol::Settings::default();

// No bytes received yet.
assert_eq!(None, reader.poll::<u32>(&settings).unwrap());

// Two bytes received.
reader.write(&[0xff, 0x00]).unwrap();
assert_eq!(None, reader.poll::<u32>(&settings).unwrap());

// Three bytes received.
reader.write(&[0x00]).unwrap();
assert_eq!(None, reader.poll::<u32>(&settings).unwrap());

// All four bytes received.
reader.write(&[0x00]).unwrap();
assert_eq!(Some(0xff000000), reader.poll::<u32>(&settings).unwrap());

Implementations

Source

impl Reader

pub fn new() -> Self

Creates a new parcel reader.

pub fn poll<P>(&mut self, settings: &Settings) -> Result<Option<P>, Error>
where P: Parcel,

Polls the reader for a value.

Returns Ok(None) if further data must be received in order to interpret the value.

Returns Ok(Some(value)) if the value is ready to be read from the stream.

Returns Err(e) on error.