pub struct Ecdh;Expand description
Stateless ECDH helper.
Implementations
Sourceimpl Ecdh
impl Ecdh
Sourcepub fn derive_public_key<P, const LIMBS: usize>(
base_point: &P,
secret: &SecretScalar<LIMBS>,
curve: &P::Curve,
) -> Pwhere
P: PointOps,
pub fn derive_public_key<P, const LIMBS: usize>(
base_point: &P,
secret: &SecretScalar<LIMBS>,
curve: &P::Curve,
) -> Pwhere
P: PointOps,
Derive a public key [secret]G from a fixed generator/base point.
Sourcepub fn keypair_from_secret<P, const LIMBS: usize>(
base_point: &P,
secret: SecretScalar<LIMBS>,
curve: &P::Curve,
) -> KeyPair<P, LIMBS>where
P: PointOps,
pub fn keypair_from_secret<P, const LIMBS: usize>(
base_point: &P,
secret: SecretScalar<LIMBS>,
curve: &P::Curve,
) -> KeyPair<P, LIMBS>where
P: PointOps,
Build a deterministic key pair from a secret scalar.
Compute a shared point [my_secret] peer_public.
Returns None when the peer public key is the identity.